# Slot: id


a globally unique schema identifier

URI: [http://w3id.org/biolink/biolinkml/meta/id](slot_uri)
## Domain and Range

[SchemaDefinition](SchemaDefinition.md) -> [Uri](Uri.md)
## Inheritance

## Children

## Used by

 * [SchemaDefinition](SchemaDefinition.md)
